From 0ebcb9388eac8e96e15fada3699fee8221bcac39 Mon Sep 17 00:00:00 2001
From: Tomas Plesnik <plesnik@ics.muni.cz>
Date: Sat, 3 Jan 2015 10:49:29 +0100
Subject: [PATCH] zmena nazvu funkce

---
 src/warden-server/sh/uninstall.sh | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/src/warden-server/sh/uninstall.sh b/src/warden-server/sh/uninstall.sh
index 666e598..c3d5423 100755
--- a/src/warden-server/sh/uninstall.sh
+++ b/src/warden-server/sh/uninstall.sh
@@ -140,7 +140,7 @@ uninstallWardenServer()
 }
 
 
-deleteSymlinks()
+removeSymlinks()
 {
 	echo -n "Checking symbolic links directory $symbin ... "
 	if [[ -d $symbin && -w $symbin ]]; then
@@ -200,8 +200,8 @@ createBackup
 # uninstall Warden server
 uninstallWardenServer || exit 1
 
-# delete symlinks from $symbin (if -s option is set)
-[[ ! -z "$symbin" ]] && deleteSymlinks
+# remove symlinks from $symbin (if -s option is set)
+[[ ! -z "$symbin" ]] && removeSymlinks
 
 echo
 echo "------------------------- Summary ---------------------------------------"
-- 
GitLab